@@ -246,7 +246,7 @@ struct babel_info *load_babel_info_from_blorb(FILE *infile, int length,
   }
   */
 
-  xmlData[length - 1] = '\0';
+  xmlData[length] = '\0';
 
   if ((babel_doc = xmlReadDoc(
           (xmlChar*)xmlData,
