@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -82,6 +82,7 @@ struct configuration_option configuration_options[] = {
   { "savegame-path", NULL },
   { "transcript-filename", NULL },
   { "command-filename", NULL },
+  { "sync-transcript", NULL }, // bool-string
   { NULL, NULL }
 };
 
@@ -229,6 +230,8 @@ int set_configuration_value(char *key, char* new_value, ...)
           (strcmp(key, "enable-font3-conversion") == 0)
           ||
           (strcmp(key, "set-tandy-bit") == 0)
+          ||
+          (strcmp(key, "sync-transcript") == 0)
           )
       {
         if (new_value == NULL)
@@ -299,6 +302,8 @@ char *get_configuration_value(char *key)
            (strcmp(key, "enable-font3-conversion") == 0)
            ||
            (strcmp(key, "set-tandy-bit") == 0)
+           ||
+           (strcmp(key, "sync-transcript") == 0)
           )
           &&
           (configuration_options[i].value == NULL)
