@@ -992,12 +992,11 @@ static int detect_and_add_z_file(char *filename, char *blorb_filename,
       ptr2 = fizmo_strdup(title);
       ptr = strrchr(ptr2, '.');
 
-      if (
-          ( (strlen(ptr) == 3)
-            && (ptr[1] == 'z')
-            && (isdigit(ptr[2]) != 0) )
+      if ( ( (strlen(ptr) == 3) && (ptr[1] == 'z') && (isdigit(ptr[2]) != 0) )
           ||
           (strcasecmp(ptr, ".dat") == 0)
+          ||
+          (strcasecmp(ptr, ".zblorb") == 0)
          )
         *ptr = '\0';
 
