@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -104,7 +104,7 @@ static bool config_files_were_parsed = false;
 //long size;
 
 
-void load_blorb(struct z_story *result, char* blorb_input_filename)
+static void load_blorb(struct z_story *result, char* blorb_input_filename)
 {
   //struct z_story *result;
   int resource_chunk_size;
@@ -390,8 +390,7 @@ void load_blorb(struct z_story *result, char* blorb_input_filename)
 }
 
 
-/*@only@*/ static struct z_story *load_z_story(char *input_filename,
-    char *blorb_filename)
+static struct z_story *load_z_story(char *input_filename, char *blorb_filename)
 {
   struct z_story *result;
   int z_file_version;
@@ -659,9 +658,6 @@ void load_blorb(struct z_story *result, char* blorb_input_filename)
   if (enable_script_after_start != 0)
     result->memory[0x11] |= 1;
 
-  result->memory[0x32] = OBEYS_SPEC_MAJOR_REVISION_NUMER;
-  result->memory[0x33] = OBEYS_SPEC_MINOR_REVISION_NUMER;
-
   result->release_code = load_word(result->memory + 0x2);
   memcpy(result->serial_code, result->memory+0x12, 6);
   result->serial_code[6] = (char)0;
@@ -964,7 +960,7 @@ void ensure_dot_fizmo_dir_exists()
 }
 
 
-/*@external@*/ void link_active_interface_to_story(bool set_only_restart_flags)
+void write_interpreter_info_into_header()
 {
   uint16_t width, height;
 
@@ -1020,11 +1016,7 @@ void ensure_dot_fizmo_dir_exists()
     if (active_interface->is_italic_available() == true)
       z_mem[1] |= 0x08;
 
-    if (
-        (active_interface->is_fixed_space_font_available() == true)
-        &&
-        (set_only_restart_flags == false)
-       )
+    if (active_interface->is_fixed_space_font_available() == true)
       z_mem[1] |= 0x10;
 
     // Write information about timed input
@@ -1070,13 +1062,17 @@ void ensure_dot_fizmo_dir_exists()
       }
     }
   }
+
+  z_mem[0x32] = OBEYS_SPEC_MAJOR_REVISION_NUMER;
+  z_mem[0x33] = OBEYS_SPEC_MINOR_REVISION_NUMER;
 }
 
 
 void fizmo_register_screen_interface(struct z_screen_interface
     *screen_interface)
 {
-  active_interface = screen_interface;
+  if (active_interface == NULL)
+    active_interface = screen_interface;
 }
 
 
@@ -1095,6 +1091,8 @@ static int parse_fizmo_config_file(char *filename)
   int c, i;
   FILE *config_file;
 
+  TRACE_LOG("Parsing config file \"%s\".\n", filename);
+
   if ((config_file = fopen(filename, "r")) == NULL)
     return 0;
 
@@ -1131,6 +1129,7 @@ static int parse_fizmo_config_file(char *filename)
 
         if (strcasecmp(key, "language") == 0)
         {
+          TRACE_LOG("locale parameter: \"%s\".\n", value);
           set_configuration_value("locale", value, "fizmo");
         }
         else if (
@@ -1141,14 +1140,24 @@ static int parse_fizmo_config_file(char *filename)
             (strcasecmp(key, "command-filename") == 0)
             )
         {
-          //printf("%s/%s\n", key, value);
+          TRACE_LOG("New configuration key/value: \"%s\", \"%s\".\n",
+              key, value);
           set_configuration_value(key, value);
         }
+        else if (strcasecmp(key, "sync-transcript") == 0)
+        {
+          if ( (value != NULL) && (strcmp(value, "") != 0) )
+            set_configuration_value("sync-transcript", "true");
+        }
         else
         {
           // Forward non-comments to interface.
           if (key[0] != '#')
+          {
+            TRACE_LOG("key/value forwarded to interface: \"%s\", \"%s\".\n",
+                key, value);
             active_interface->parse_config_parameter(key, value);
+          }
 
           // Ignore wrong config values.
         }
@@ -1481,7 +1490,7 @@ void fizmo_start(char* input_filename, char *blorb_filename,
         Z_STYLE_ROMAN);
 #endif /* DISABLE_OUTPUT_HISTORY */
 
-  link_active_interface_to_story(false);
+  write_interpreter_info_into_header();
 
   // REVISIT: Implement general initalization for restore / restart etc.
   active_window_number = 0;
@@ -1526,7 +1535,7 @@ void fizmo_start(char* input_filename, char *blorb_filename,
         // of 'Flags 2' in the header, at address $10) and the "use fixed pitch
         // font" bit (bit 1 of 'Flags 2').
 
-        flags2 = z_mem[0x10] & 0x3;
+        flags2 = z_mem[0x11] & 0x3;
 
         drop_z_stack_words(z_stack_index - z_stack);
         number_of_stack_frames = 0;
@@ -1562,10 +1571,10 @@ void fizmo_start(char* input_filename, char *blorb_filename,
 
         active_interface->reset_interface();
 
-        link_active_interface_to_story(true);
+        write_interpreter_info_into_header();
 
-        z_mem[0x10] &= 0xfc;
-        z_mem[0x10] |= flags2;
+        z_mem[0x11] &= 0xfc;
+        z_mem[0x11] |= flags2;
 
         terminate_interpreter = INTERPRETER_QUIT_NONE;
       }
