@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,7 @@
 #include "../c/sound_interface.h"
 #include "blockbuf.h"
 
-#define FIZMO_VERSION "0.6.4"
+#define FIZMO_VERSION "0.6.8"
 
 #define FIZMO_INTERPRETER_NUMBER 6
 /*
@@ -73,7 +73,7 @@ void fizmo_register_screen_interface(
     struct z_screen_interface *screen_interface);
 void fizmo_register_sound_interface(
     struct z_sound_interface *sound_interface);
-void link_active_interface_to_story(bool set_only_restart_flags);
+void write_interpreter_info_into_header();
 void fizmo_start(char* z_story_filename, char *blorb_filename,
     char *restore_on_start_filename);
 void fizmo_new_screen_size(uint8_t width, uint8_t height);
