@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -1348,10 +1348,11 @@ void repeat_paragraphs_from_history(OUTPUTHISTORY *history,
         output_start_foreground_colour,
         output_start_background_colour);
 
-    target->set_colour(
-        output_start_foreground_colour,
-        output_start_background_colour,
-        (int16_t)history->window_number);
+    if (active_interface->is_colour_available() == true)
+      target->set_colour(
+          output_start_foreground_colour,
+          output_start_background_colour,
+          (int16_t)history->window_number);
   }
 
   if ((metadata_index = output_start_metadata_index) == -1)
@@ -1447,9 +1448,13 @@ void repeat_paragraphs_from_history(OUTPUTHISTORY *history,
               (z_style)/*@-nullderef@*/history->history_metadata_buffer
               /*@+nullderef@*/[metadata_index].parameter1);
         }
-        else if (/*@-nullderef@*/history->history_metadata_buffer
-            /*@+nullderef@*/[metadata_index].metadata_type
-            == HISTORY_METADATA_TYPE_COLOUR)
+        else if (
+            (/*@-nullderef@*/history->history_metadata_buffer
+             /*@+nullderef@*/[metadata_index].metadata_type
+             == HISTORY_METADATA_TYPE_COLOUR)
+            &&
+            (active_interface->is_colour_available() == true)
+            )
         {
           TRACE_LOG("Setting interface colour from historized metadata.\n");
           /*@-nullderef@*/
@@ -1618,7 +1623,8 @@ void init_scrollback_count_wordwrapper(int screen_width, int left_padding)
         &history_wrapper_output_target,
         (void*)NULL,
         left_padding,
-        true);
+        true,
+        false);
   else
     wordwrap_adjust_line_length(scrollback_count_wordwrapper, scrollback_width);
 }
