@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -111,21 +111,16 @@ static void stream_2_wrapped_output_destination(z_ucs *z_ucs_output,
   int len;
 
   // FIMXE: Re-implement for various output charsets.
-  //fwprintf(stream_2, z_ucs_output);
 
-  /*
-  // Latin1-output
-  while (*z_ucs_output != 0)
+  if (*z_ucs_output != 0)
   {
-    fputc(z_ucs_to_latin1(*z_ucs_output), stream_2);
-    z_ucs_output++;
-  }
-  */
-
-  while (*z_ucs_output != 0)
-  {
-    len = z_ucs_to_utf_8(buf, &z_ucs_output, 128);
-    fwrite(buf, 1, len-1, stream_2);
+    while (*z_ucs_output != 0)
+    {
+      len = z_ucs_to_utf_8(buf, &z_ucs_output, 128);
+      fwrite(buf, 1, len-1, stream_2);
+    }
+    if (strcmp(get_configuration_value("sync-transcript"), "true") == 0)
+      fflush(stream_2);
   }
 }
 /*@+paramuse@*/
@@ -157,7 +152,10 @@ void init_streams()
       &streams_wordwrap_target,
       NULL,
       true,
-      DEFAULT_STREAM_2_LEFT_PADDING);
+      DEFAULT_STREAM_2_LEFT_PADDING,
+      (strcmp(get_configuration_value("sync-transcript"), "true") == 0
+       ? true
+       : false));
   /*@+mustfreeonly@*/
 
   if (strcmp(get_configuration_value("start-script-when-story-starts"), "true")
@@ -315,7 +313,7 @@ void ask_for_input_stream_filename(void)
   }
   while (input_length == 0);
 
-  for (i=0; i<=input_length; i++)
+  for (i=0; i<input_length; i++)
     last_script_filename[i]
       = zscii_input_char_to_z_ucs(current_filename_buffer[i]);
   last_script_filename[i] = 0;
@@ -450,7 +448,7 @@ void ask_for_stream2_filename()
   }
   while (input_length == 0);
 
-  for (i=0; i<=input_length; i++)
+  for (i=0; i<input_length; i++)
     last_script_filename[i]
       = zscii_input_char_to_z_ucs(current_filename_buffer[i]);
   last_script_filename[i] = 0;
@@ -534,6 +532,8 @@ static void stream_2_output(z_ucs *z_ucs_output)
       wordwrap_output_left_padding(stream_2_wrapper);
       fputs("---\n\n", stream_2);
       wordwrap_output_left_padding(stream_2_wrapper);
+      if (strcmp(get_configuration_value("sync-transcript"), "true") == 0)
+        fflush(stream_2);
     }
 
     if (bool_equal(lower_window_buffering_active, true))
@@ -651,7 +651,7 @@ void ask_for_stream4_filename_if_required(bool UNUSED(dont_output_current_line))
 
     stream_1_active = stream_1_active_buf;
 
-    for (i=0; i<=input_length; i++)
+    for (i=0; i<input_length; i++)
       last_stream_4_filename[i]
         = zscii_input_char_to_z_ucs(current_filename_buffer[i]);
     last_stream_4_filename[i] = 0;
@@ -1266,6 +1266,10 @@ void close_streams(z_ucs *error_message)
 {
   TRACE_LOG("Closing all streams.\n");
 
+  // Close the interface first. This will allow stream 2 to capture
+  // any pending output.
+  (void)close_interface(error_message);
+
   if (stream_2 != NULL)
     close_script_file();
 
@@ -1275,8 +1279,6 @@ void close_streams(z_ucs *error_message)
     stream_4 = NULL;
   }
 
-  (void)close_interface(error_message);
-
 #ifdef ENABLE_TRACING
   turn_off_trace();
 #endif /* ENABLE_TRACING */
