@@ -1,4 +1,35 @@
 
+/* text.c
+ *
+ * This file is part of fizmo.
+ *
+ * Copyright (c) 2009 Christoph Ender.
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. The name of the author may not be used to endorse or promote products
+ *    derived from this software without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+
 #ifndef text_c_INCLUDED
 #define text_c_INCLUDED
 
@@ -2006,7 +2037,7 @@ void opcode_show_status(void)
 
 void opcode_read_char(void)
 {
-  static z_ucs buf[] = { 0, 0 };
+  //static z_ucs buf[] = { 0, 0 };
   static zscii command_input;
   char *time_output;
   int tenth_seconds_elapsed = -1;
@@ -2070,12 +2101,15 @@ void opcode_read_char(void)
 
     if (input_char == -1)
       input_char = 0;
+    /*
+    // No output of input in case of read_char.
     else
     {
       *buf = input_char;
       (void)streams_z_ucs_output_user_input(buf);
     }
     (void)streams_z_ucs_output_user_input(z_ucs_newline_string);
+    */
 
     set_variable(z_res_var, input_char);
 
@@ -2118,9 +2152,12 @@ void opcode_read_char(void)
       }
     }
 
+    /*
     *buf = input_char;
+    // No output of input in case of read_char.
     (void)streams_z_ucs_output_user_input(buf);
     (void)streams_z_ucs_output_user_input(z_ucs_newline_string);
+    */
     set_variable(z_res_var, input_char);
     TRACE_LOG("Reading single character done.\n");
   }
