@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -189,7 +189,7 @@ void opcode_restore_undo(void)
     free(frame_to_restore->dynamic_memory);
     free(frame_to_restore);
 
-    link_active_interface_to_story(true);
+    write_interpreter_info_into_header();
 
     result = 2;
   }
