@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -505,7 +505,8 @@ WORDWRAP *wordwrap_new_wrapper(size_t line_length,
     //void (*wrapped_text_output_destination)(z_ucs *output,
     //  /*@null@*/ void *parameter),
     /*@null@*/ void *destination_parameter,
-    bool add_newline_after_full_line, int left_side_padding)
+    bool add_newline_after_full_line, int left_side_padding,
+    bool flush_after_newline)
 {
   WORDWRAP *new_wrapper;
   size_t bytes_to_allocate = sizeof(WORDWRAP);
@@ -532,6 +533,7 @@ WORDWRAP *wordwrap_new_wrapper(size_t line_length,
   new_wrapper->last_line_was_completely_filled = false;
   new_wrapper->left_side_padding = left_side_padding;
   //new_wrapper->has_received_any_output = false;
+  new_wrapper->flush_after_newline = flush_after_newline;
 
   new_wrapper->output_buffer_size = 0;
   new_wrapper->output_buffer = NULL;
@@ -558,7 +560,7 @@ WORDWRAP *wordwrap_new_wrapper(size_t line_length,
   resize_output_buffer(
       // new_wrapper->line_length doesn't have to be defined
       /*@-compdef@*/ new_wrapper /*@+compdef@*/, 
-      (size_t)(line_length * 4));
+      (size_t)(flush_after_newline == true ? line_length+2 : line_length*4));
 
   // new_wrapper->line_length is set in wordwrap_adjust_line_length.
   // new_wrapper->output_buffer is defined in wordwrap_adjust_line_length.
@@ -692,6 +694,13 @@ void wordwrap_wrap_z_ucs(WORDWRAP *wrapper, z_ucs *input)
       input += len;
     }
   }
+
+  if (
+      (wrapper->flush_after_newline == true)
+      &&
+      (z_ucs_chr(wrapper->output_buffer, Z_UCS_NEWLINE) != NULL)
+     )
+    wordwrap_flush_buffer(wrapper, false);
 }
 
 
@@ -757,7 +766,11 @@ void wordwrap_set_line_index(WORDWRAP *wrapper, int new_line_index)
 
 void wordwrap_adjust_line_length(WORDWRAP *wrapper, size_t new_line_length)
 {
-  if (new_line_length * 3 < wrapper->output_buffer_size)
+  if (wrapper->flush_after_newline == true)
+  {
+    resize_output_buffer(wrapper, new_line_length + 2);
+  }
+  else if (new_line_length * 3 < wrapper->output_buffer_size)
   {
     resize_output_buffer(wrapper, new_line_length * 4);
   }
