@@ -3,7 +3,7 @@
  *
  * This file is part of fizmo.
  *
- * Copyright (c) 2009 Christoph Ender.
+ * Copyright (c) 2010 Christoph Ender.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,10 +39,10 @@
 #include "../fizmo/streams.h"
 #include "../fizmo/locales.h"
 
-
+static char* interface_name = "simple-c";
 
 char *simple_c_get_interface_name()
-{ return "simple-c"; }
+{ return interface_name; }
 
 bool simple_c_return_false()
 { return false; }
